@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-password-manager.h,v 1.3 2004/01/01 22:54:11 chpe Exp $
+ *  $Id: ephy-password-manager.h,v 1.5 2004/08/21 16:33:58 chpe Exp $
  */
 
 #ifndef EPHY_PASSWORD_MANAGER_H
@@ -29,15 +29,15 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_PASSWORD_MANAGER		(ephy_password_manager_get_type ())
 #define EPHY_PASSWORD_MANAGER(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_PASSWORD_MANAGER, EphyPasswordManager))
-#define EPHY_PASSWORD_MANAGER_IFACE(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_PASSWORD_MANAGER, EphyPasswordManagerIFace))
+#define EPHY_PASSWORD_MANAGER_IFACE(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_PASSWORD_MANAGER, EphyPasswordManagerIface))
 #define EPHY_IS_PASSWORD_MANAGER(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_PASSWORD_MANAGER))
 #define EPHY_IS_PASSWORD_MANAGER_IFACE(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_PASSWORD_MANAGER))
-#define EPHY_PASSWORD_MANAGER_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_PASSWORD_MANAGER, EphyPasswordManagerIFace))
+#define EPHY_PASSWORD_MANAGER_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_PASSWORD_MANAGER, EphyPasswordManagerIface))
 
 #define EPHY_TYPE_PASSWORD_INFO			(ephy_password_info_get_type ())
 
 typedef struct EphyPasswordManager	EphyPasswordManager;
-typedef struct EphyPasswordManagerIFace	EphyPasswordManagerIFace;
+typedef struct EphyPasswordManagerIface	EphyPasswordManagerIface;
 
 typedef struct
 {
@@ -46,10 +46,13 @@ typedef struct
 	char *password;
 } EphyPasswordInfo;
 
-struct EphyPasswordManagerIFace
+struct EphyPasswordManagerIface
 {
 	GTypeInterface base_iface;
 
+	/* Signals */
+	void	(* changed)	(EphyPasswordManager *manager);
+
 	/* Methods */
 	void	(* add)		(EphyPasswordManager *manager,
 				 EphyPasswordInfo *info);
