@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: EphyHeaderSniffer.h,v 1.13 2004/07/20 18:15:45 marco Exp $
+ * $Id: EphyHeaderSniffer.h,v 1.13.4.1 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-embed-persist.h"
@@ -50,7 +50,9 @@
 #include <nsIDOMDocument.h>
 #include <nsIAuthPrompt.h>
 #include <nsIPromptService.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 class EphyHeaderSniffer : public nsIWebProgressListener,
 			  public nsIAuthPrompt
