@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.39.4.5 2004/11/22 22:12:36 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.39.4.6 2005/01/11 14:41:07 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -191,7 +191,7 @@ nsresult EventContext::Unescape (const nsACString &aEscaped, nsACString &aUnesca
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	nsEmbedString unescaped;
-	rv = escaper->UnEscapeNonAsciiURI (encoding, aEscaped, unescaped);
+	rv = escaper->UnEscapeURIForUI (encoding, aEscaped, unescaped);
 	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && unescaped.Length(), NS_ERROR_FAILURE);
 
 	NS_UTF16ToCString (unescaped, NS_CSTRING_ENCODING_UTF8, aUnescaped);
