@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.14 2004/07/30 19:56:08 chpe Exp $
+ *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.14.4.2 2004/11/13 19:56:49 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -28,12 +28,14 @@
 
 #ifdef HAVE_MOZILLA_PSM
 
-#include "MozillaPrivate.h"
+#include "EphyUtils.h"
 
 #include <nsIServiceManager.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
+#define MOZILLA_STRICT_API
 #include <nsEmbedString.h>
+#undef MOZILLA_STRICT_API
 
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkimage.h>
@@ -146,7 +148,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	PRUint32 i;
 
 	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
-	GtkWidget *gparent = MozillaFindGtkParent (parent);
+	GtkWidget *gparent = EphyUtils::FindGtkParent (parent);
 
 	dialog = gtk_dialog_new_with_buttons ("",
 					      GTK_WINDOW (gparent),
