@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.83.4.4 2004/11/13 19:56:49 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.83.4.7 2005/01/28 22:56:39 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -74,8 +74,9 @@ static void mozilla_embed_new_window_cb		(GtkMozEmbed *embed,
 						 MozillaEmbed *membed);
 static void mozilla_embed_security_change_cb	(GtkMozEmbed *embed, 
 						 gpointer request,
-						 guint state, MozillaEmbed *membed);
-static EmbedSecurityLevel mozilla_embed_security_level (MozillaEmbed *membed);
+						 PRUint32 state,
+						 MozillaEmbed *membed);
+static EmbedSecurityLevel mozilla_embed_security_level (PRUint32 state);
 
 #define MOZILLA_EMBED_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), MOZILLA_TYPE_EMBED, MozillaEmbedPrivate))
 
@@ -90,7 +91,6 @@ typedef enum
 struct MozillaEmbedPrivate
 {
 	EphyBrowser *browser;
-	guint security_state;
 	MozillaEmbedLoadState load_state;
 };
 
@@ -262,7 +262,6 @@ mozilla_embed_init (MozillaEmbed *embed)
 {
         embed->priv = MOZILLA_EMBED_GET_PRIVATE (embed);
 	embed->priv->browser = new EphyBrowser ();
-	embed->priv->security_state = STATE_IS_UNKNOWN;
 
 	g_signal_connect_object (G_OBJECT (embed), "location",
 				 G_CALLBACK (mozilla_embed_location_changed_cb),
@@ -634,26 +633,33 @@ impl_shistory_go_nth (EphyEmbed *embed,
 }
 
 static void
-impl_get_security_level (EphyEmbed *embed, 
+impl_get_security_level (EphyEmbed *embed,
                          EmbedSecurityLevel *level,
                          char **description)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (embed)->priv;
 
-	g_return_if_fail (description != NULL && level != NULL);
-
-	*description = NULL;
-	*level = STATE_IS_UNKNOWN;
+	if (level) *level = STATE_IS_UNKNOWN;
+	if (description) *description = NULL;
 
 	nsresult rv;
+	PRUint32 state;
 	nsEmbedCString desc;
-	rv = mpriv->browser->GetSecurityDescription (desc);
+	rv = mpriv->browser->GetSecurityInfo (&state, desc);
 	if (NS_FAILED (rv)) return;
 
-	*description = g_strdup (desc.get());
-	*level = mozilla_embed_security_level (MOZILLA_EMBED (embed));
+	if (level) *level = mozilla_embed_security_level (state);
+	if (description) *description = g_strdup (desc.get());
 }
 
+static void
+impl_show_page_certificate (EphyEmbed *embed)
+{
+	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (embed)->priv;
+
+	mpriv->browser->ShowCertificate ();
+}
+	
 static void
 impl_print (EphyEmbed *embed)
 {
@@ -885,7 +891,11 @@ mozilla_embed_dom_key_down_cb (GtkMozEmbed *embed, gpointer dom_event,
 	EventContext ctx;
 	ctx.Init (mpriv->browser);
 	rv = ctx.GetKeyEventInfo (ev, info);
-	if (NS_FAILED (rv)) return ret;
+	if (NS_FAILED (rv))
+	{
+		g_object_unref (info);
+		return ret;
+	}
 
 	if ((info->keycode == nsIDOMKeyEvent::DOM_VK_F10 &&
 	    (info->modifier == GDK_SHIFT_MASK ||
@@ -1077,24 +1087,19 @@ mozilla_embed_new_window_cb (GtkMozEmbed *embed,
 static void
 mozilla_embed_security_change_cb (GtkMozEmbed *embed, 
 				  gpointer requestptr,
-				  guint state, 
+				  PRUint32 state,
 				  MozillaEmbed *membed)
 {
-	EmbedSecurityLevel level;
-
-	membed->priv->browser->SetSecurityInfo (static_cast<nsIRequest*>(requestptr));
-	membed->priv->security_state = state;
-	level = mozilla_embed_security_level (membed);
-
-	g_signal_emit_by_name (membed, "ge_security_change", level);
+	g_signal_emit_by_name (membed, "ge_security_change",
+			       mozilla_embed_security_level (state));
 }
 
 static EmbedSecurityLevel
-mozilla_embed_security_level (MozillaEmbed *membed)
+mozilla_embed_security_level (PRUint32 state)
 {
 	EmbedSecurityLevel level;
 
-	switch (membed->priv->security_state)
+	switch (state)
         {
         case nsIWebProgressListener::STATE_IS_INSECURE:
                 level = STATE_IS_INSECURE;
@@ -1145,6 +1150,7 @@ ephy_embed_iface_init (EphyEmbedIface *iface)
 	iface->shistory_get_pos = impl_shistory_get_pos;
 	iface->shistory_go_nth = impl_shistory_go_nth;
 	iface->get_security_level = impl_get_security_level;
+	iface->show_page_certificate = impl_show_page_certificate;
 	iface->find_next = impl_find_next;
 	iface->activate = impl_activate;
 	iface->find_set_properties = impl_find_set_properties;
