@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.22 2004/07/02 09:03:41 marco Exp $
+ *  $Id: ephy-gui.c,v 1.22.4.6 2004/12/20 12:30:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,13 +36,78 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkwindow.h>
+#include <gtk/gtkversion.h>
+#include <gtk/gtkicontheme.h>
+#include <gtk/gtktreeselection.h>
 
-/* Styles for tab labels */
-GtkStyle *loading_text_style = NULL;
-GtkStyle *new_text_style = NULL;
+void
+ephy_gui_sanitise_popup_position (GtkMenu *menu,
+				  GtkWidget *widget,
+				  gint *x,
+				  gint *y)
+{
+	GdkScreen *screen = gtk_widget_get_screen (widget);
+	gint monitor_num;
+	GdkRectangle monitor;
+	GtkRequisition req;
+
+	g_return_if_fail (widget != NULL);
+
+	gtk_widget_size_request (GTK_WIDGET (menu), &req);
+
+	monitor_num = gdk_screen_get_monitor_at_point (screen, *x, *y);
+	gtk_menu_set_monitor (menu, monitor_num);
+	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+
+	*x = CLAMP (*x, monitor.x, monitor.x + MAX (0, monitor.width - req.width));
+	*y = CLAMP (*y, monitor.y, monitor.y + MAX (0, monitor.height - req.height));
+}
+
+void
+ephy_gui_menu_position_tree_selection (GtkMenu   *menu,
+				       gint      *x,
+				       gint      *y,
+				       gboolean  *push_in,
+				       gpointer  user_data)
+{
+	GtkTreeSelection *selection;
+	GList *selected_rows;
+	GtkTreeModel *model;
+	GtkTreeView *tree_view = GTK_TREE_VIEW (user_data);
+	GtkWidget *widget = GTK_WIDGET (user_data);
+	GtkRequisition req;
+	GdkRectangle visible;
+
+	gtk_widget_size_request (GTK_WIDGET (menu), &req);
+	gdk_window_get_origin (widget->window, x, y);
+
+	*x += (widget->allocation.width - req.width) / 2;
+
+	/* Add on height for the treeview title */
+	gtk_tree_view_get_visible_rect (tree_view, &visible);
+	*y += widget->allocation.height - visible.height;
+
+	selection = gtk_tree_view_get_selection (tree_view);
+	selected_rows = gtk_tree_selection_get_selected_rows (selection, &model);
+	if (selected_rows)
+	{
+		GdkRectangle cell_rect;
+
+		gtk_tree_view_get_cell_area (tree_view, selected_rows->data,
+					     NULL, &cell_rect);
+
+		*y += CLAMP (cell_rect.y + cell_rect.height, 0, visible.height);
+
+		g_list_foreach (selected_rows, (GFunc)gtk_tree_path_free, NULL);
+		g_list_free (selected_rows);
+	}
+
+	ephy_gui_sanitise_popup_position (menu, widget, x, y);
+}
 
 /**
- * gul_gui_menu_position_under_widget:
+ * ephy_gui_menu_position_under_widget:
  */
 void
 ephy_gui_menu_position_under_widget (GtkMenu   *menu,
@@ -52,7 +117,6 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 				     gpointer	user_data)
 {
 	GtkWidget *w = GTK_WIDGET (user_data);
-	gint screen_width, screen_height;
 	GtkRequisition requisition;
 	gboolean rtl;
 
@@ -61,10 +125,6 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	gdk_window_get_origin (w->window, x, y);
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
-	/* FIXME multihead */
-	screen_width = gdk_screen_width ();
-	screen_height = gdk_screen_height ();
-
 	if (rtl)
 	{
 		*x += w->allocation.x + w->allocation.width - requisition.width;
@@ -76,8 +136,7 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 
 	*y += w->allocation.y + w->allocation.height;
 
-	*x = CLAMP (*x, 0, MAX (0, screen_width - requisition.width));
-	*y = CLAMP (*y, 0, MAX (0, screen_height - requisition.height));
+	ephy_gui_sanitise_popup_position (menu, w, x, y);
 }
 
 gboolean
@@ -112,6 +171,8 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 					GTK_RESPONSE_CANCEL,
 					_("_Overwrite"), GTK_RESPONSE_ACCEPT,
 					NULL);
+	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
+
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, TRUE, TRUE, 12);
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
@@ -121,6 +182,7 @@ ephy_gui_confirm_overwrite_file (GtkWidget *parent, const char *filename)
 	label = gtk_label_new (NULL);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_label_set_markup (GTK_LABEL (label), question);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	gtk_widget_show_all (hbox);
 
@@ -246,3 +308,42 @@ ephy_gui_is_middle_click (void)
 
 	return new_tab;
 }
+
+void
+ephy_gui_set_default_window_icon (GtkWindow *window)
+{
+#if GTK_CHECK_VERSION (2, 5, 4)
+	gtk_window_set_icon_name (window, "web-browser");
+#else
+	const char *icon_path;
+	GdkPixbuf *icon = NULL;
+	GtkIconTheme *icon_theme;
+	GtkIconInfo *icon_info;
+
+	icon_theme = gtk_icon_theme_get_default ();
+	icon_info = gtk_icon_theme_lookup_icon (icon_theme, "web-browser", -1, 0);
+
+	if (icon_info != NULL)
+	{
+		icon_path = gtk_icon_info_get_filename (icon_info);
+
+		if (icon_path != NULL)
+		{
+			icon = gdk_pixbuf_new_from_file (icon_path, NULL);
+		}
+
+		gtk_icon_info_free (icon_info);
+	}
+	else
+	{
+		g_warning ("Web browser gnome icon not found");
+	}
+
+	gtk_window_set_icon (GTK_WINDOW (window), icon);
+
+	if (icon != NULL)
+	{
+		g_object_unref (icon);
+	}
+#endif
+}
