@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.11 2004/07/02 09:03:41 marco Exp $
+ *  $Id: ephy-gui.h,v 1.11.4.3 2004/11/07 20:28:22 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
@@ -30,6 +30,17 @@
 
 G_BEGIN_DECLS
 
+void		ephy_gui_sanitise_popup_position	 (GtkMenu *menu,
+							  GtkWidget *parent_widget,
+							  gint *x,
+							  gint *y);
+
+void		ephy_gui_menu_position_tree_selection    (GtkMenu   *menu,
+							  gint      *x,
+							  gint      *y,
+							  gboolean  *push_in,
+							  gpointer  user_data);
+
 void		ephy_gui_menu_position_under_widget	 (GtkMenu   *menu,
 							  gint      *x,
 							  gint      *y,
@@ -49,6 +60,8 @@ void		ephy_gui_help				 (GtkWindow *parent,
 							  const char *file_name,
 							  const char *link_id);
 
+void		ephy_gui_set_default_window_icon	 (GtkWindow *window);
+
 G_END_DECLS
 
 #endif
