@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-state.c,v 1.27.10.1 2004/10/08 12:16:39 marco Exp $
+ *  $Id: ephy-state.c,v 1.27.10.3 2004/10/31 19:43:12 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -124,8 +124,7 @@ ensure_states (void)
 static void
 ephy_state_window_set_size (GtkWidget *window, EphyNode *node)
 {
-	int width;
-	int height;
+	int width, height, w = -1, h = -1;
 	gboolean maximize, size;
 
 	width = ephy_node_get_property_int (node, EPHY_NODE_STATE_PROP_WIDTH);
@@ -133,7 +132,8 @@ ephy_state_window_set_size (GtkWidget *window, EphyNode *node)
 	maximize = ephy_node_get_property_boolean (node, EPHY_NODE_STATE_PROP_MAXIMIZE);
 	size = ephy_node_get_property_boolean (node, EPHY_NODE_STATE_PROP_SIZE);
 
-	if (size)
+	gtk_window_get_default_size (GTK_WINDOW (window), &w, &h);
+	if (size && w == -1 && h == -1)
 	{
 		GdkScreen *screen;
 		int screen_width, screen_height;
