@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-action.c,v 1.6 2004/02/04 22:25:27 chpe Exp $
+ *  $Id: ephy-zoom-action.c,v 1.7.10.1 2004/10/31 19:43:12 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,7 +134,6 @@ proxy_menu_activate_cb (GtkMenuItem *menu_item, EphyZoomAction *action)
 
 	if (zoom != action->priv->zoom)
 	{
-	g_print ("zoom_to_level emit, to %f from %f\n", zoom, action->priv->zoom);
 		g_signal_emit (action, signals[ZOOM_TO_LEVEL_SIGNAL], 0, zoom);
 	}
 }
@@ -190,7 +189,6 @@ ephy_zoom_action_set_property (GObject *object,
 	{
 		case PROP_ZOOM:
 			action->priv->zoom = g_value_get_float (value);
-			g_object_notify (object, "zoom");
 			break;
 	}
 }
