@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-new-bookmark.c,v 1.43 2004/07/23 10:03:56 marco Exp $
+ *  $Id: ephy-new-bookmark.c,v 1.43.4.2 2004/10/08 12:17:26 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -267,7 +267,7 @@ ephy_new_bookmark_construct (EphyNewBookmark *editor)
 
 	ephy_state_add_window (GTK_WIDGET(editor),
 			       "new_bookmark",
-		               280, 240,
+		               280, 240, FALSE,
 			       EPHY_STATE_WINDOW_SAVE_SIZE);
 
 	gtk_window_set_title (GTK_WINDOW (editor),
@@ -325,7 +325,8 @@ duplicate_dialog_construct (GtkWindow *parent,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
 					      NULL);
-	
+	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
+
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
