@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.85.4.3 2004/12/19 14:20:42 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.85.4.4 2005/01/30 20:12:08 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1088,7 +1088,7 @@ create_language_section (EphyDialog *dialog)
 }
 
 static char*
-get_download_button_label ()
+get_download_button_label (void)
 {
 	char *key, *label, *downloads_path, *converted_dp;
 
