@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.131.4.4 2004/11/14 16:04:35 chpe Exp $
+ *  $Id: window-commands.c,v 1.131.4.5 2004/12/30 17:52:21 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -176,7 +176,7 @@ window_cmd_file_send_to	(GtkAction *action,
                            "?Subject=", title,
                            "&Body=", location, NULL);
 
-	ephy_embed_load_url (embed, url);
+	gnome_vfs_url_show (url);
 
 	g_free (title);
 	g_free (location);
